@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 __title__ = 'pelican-git'
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 __author__ = 'Ha.Minh'
 __email__ = 'minhhh@minhhuyha.info'
-__url__ = 'https://github.com/minhhh/pelican-git'
-__desc__ = 'Easily embed GitHub Git file in your Pelican articles.'
+__url__ = 'https://github.com/minhhh/pelican_git'
+__desc__ = 'Easily embed Github files in your Pelican articles.'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2014'
 
